@@ -22,6 +22,7 @@
 #include "dockconfigview.h"
 #include "dockcorona.h"
 #include "panelshadows_p.h"
+#include "screenpool.h"
 #include "visibilitymanager.h"
 #include "../liblattedock/extras.h"
 
@@ -746,7 +747,17 @@ inline void DockView::syncGeometry()
         QRect availableScreenRect{this->screen()->geometry()};
 
         if (formFactor() == Plasma::Types::Vertical) {
-            freeRegion = corona()->availableScreenRegion(this->containment()->screen());
+            auto dockCorona = qobject_cast<DockCorona *>(corona());
+
+            int screenId = -1;
+
+            if (qGuiApp->primaryScreen()) {
+                QString screenName = qGuiApp->primaryScreen()->name();
+                screenId = dockCorona->screenPool()->id(screenName);
+            }
+
+            int fixedScreen = (onPrimary() && screenId != -1) ? screenId : this->containment()->screen();
+            freeRegion = corona()->availableScreenRegion(fixedScreen);
             maximumRect = maximumNormalGeometry();
             QRegion availableRegion = freeRegion.intersected(maximumRect);
             availableScreenRect = freeRegion.intersected(maximumRect).boundingRect();
